==> maven-jdocbook-plugin-2.1.1-sources.jar: org/jboss/jdocbook/i18n/TranslationBuilder.java <==
/*
 * jDocBook, processing of DocBook sources as a Maven plugin
 *
 * Copyright (c) 2008, Red Hat Middleware LLC or third-party contributors as
 * indicated by the @author tags or express copyright attribution
 * statements applied by the authors.  All third-party contributions are
 * distributed under license by Red Hat Middleware LLC.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 *
 */

package org.jboss.jdocbook.i18n;

import java.io.File;

import org.jboss.jdocbook.Options;
import org.jboss.jdocbook.JDocBookProcessException;

/**
 * Contract for applying the translators work (PO file) back into XML in
 * preparation for XSLT processing.
 *
 * @author Steve Ebersole
 */
public interface TranslationBuilder {
	/**
	 *
	 * @param masterFile The master DocBook source
	 * @param poDirectory The directory containing PO files
	 * @param targetDirectory The directory into which to generate the translated XML
	 * @param options The user options
	 * @throws JDocBookProcessException unable to apply PO translations
	 */
	public void buildTranslation(File masterFile, File poDirectory, File targetDirectory, Options options)
			throws JDocBookProcessException;
}

==> maven-jdocbook-plugin-2.2.0-sources.jar: org/jboss/jdocbook/i18n/TranslationBuilder.java <==
/*
 * jDocBook, processing of DocBook sources as a Maven plugin
 *
 * Copyright (c) 2009, Red Hat Middleware LLC or third-party contributors as
 * indicated by the @author tags or express copyright attribution
 * statements applied by the authors.  All third-party contributions are
 * distributed under license by Red Hat Middleware LLC.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.jboss.jdocbook.i18n;

import org.jboss.jdocbook.JDocBookProcessException;

/**
 * Contract for applying the translators work (PO file) back into XML in
 * preparation for XSLT processing.
 *
 * @author Steve Ebersole
 */
public interface TranslationBuilder {
	/**
	 * Process the translation PO files into a set of translated XML files.
	 *
	 * @throws JDocBookProcessException unable to apply PO translations
	 */
	public void buildTranslations() throws JDocBookProcessException;
}
